*species*
=========

**spe**\ctral **c**\ haracterization and **i**\ nference for **e**\ xoplanet **s**\ cience

.. container::

    |PyPI Status| |Python Versions| |CI Status| |Docs Status| |Code Coverage| |Code Quality| |License|

*species* is a toolkit for atmospheric characterization of directly imaged exoplanets. It provides a coherent framework for spectral and photometric analysis which builds on publicly-available data and models from various resources.

There are tools available for grid and free retrievals using Bayesian inference, synthetic photometry, interpolating a variety atmospheric and evolutionary model grids (including the possibility to add a custom grid), color-magnitude and color-color diagrams, empirical spectral analysis, spectral and photometric calibration, and analysis of emission lines. The package has been released on `PyPI <https://pypi.org/project/species/>`_ and is actively developed and maintained on `Github <https://github.com/tomasstolker/species>`_.

**Important:** Importing the *species* package had become slow because of the many classes and functions that were implicitly imported. The initialization of the package has therefore been adjusted. Any functionalities should now be explicitly imported from the modules that they are part of.

Documentation
-------------

Documentation can be found at `http://species.readthedocs.io <http://species.readthedocs.io>`_.

Tutorials
---------

There are several `Jupyter notebooks <https://species.readthedocs.io/en/latest/tutorials.html>`_ with tutorials for various types of analyses and functionalities.

Attribution
-----------

Please cite `Stolker et al. (2020) <https://ui.adsabs.harvard.edu/abs/2020A%26A...635A.182S/abstract>`_ whenever results from *species* are used in a publication. Please also make sure to give credit to the relevant papers regarding the use of the publicly available data that *species* benefits from.

Contributing
------------

Contributions are welcome so please consider `forking <https://help.github.com/en/articles/fork-a-repo>`_ the repository and creating a `pull request <https://github.com/tomasstolker/species/pulls>`_. Bug reports and feature requests can be provided by creating an `issue <https://github.com/tomasstolker/species/issues>`_ on the Github page.

License
-------

Copyright 2018-2024 Tomas Stolker

*species* is distributed under the MIT License. See `LICENSE <https://github.com/tomasstolker/species/blob/main/LICENSE>`_ for the terms and conditions.

.. |PyPI Status| image:: https://img.shields.io/pypi/v/species
   :target: https://pypi.python.org/pypi/species

.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/species
   :target: https://pypi.python.org/pypi/species

.. |CI Status| image:: https://github.com/tomasstolker/species/workflows/CI/badge.svg?branch=main
   :target: https://github.com/tomasstolker/species/actions

.. |Docs Status| image:: https://img.shields.io/readthedocs/species
   :target: http://species.readthedocs.io

.. |Code Coverage| image:: https://codecov.io/gh/tomasstolker/species/branch/main/graph/badge.svg?token=LSSCPMJ5JH
   :target: https://codecov.io/gh/tomasstolker/species

.. |Code Quality| image:: https://img.shields.io/codefactor/grade/github/tomasstolker/species
   :target: https://www.codefactor.io/repository/github/tomasstolker/species

.. |License| image:: https://img.shields.io/github/license/tomasstolker/species
   :target: https://github.com/tomasstolker/species/blob/main/LICENSE
